import unittest
import logging
import sys
import os
import time
from unittest.mock import patch, Mock

import graphsignal
from graphsignal.workload_run import WorkloadRun

logger = logging.getLogger('graphsignal')


class WorkloadRunTest(unittest.TestCase):
    def setUp(self):
        graphsignal.configure(
            api_key='k1',
            workload_name='w1',
            debug_mode=True)

    def tearDown(self):
        graphsignal.shutdown()


    def test_env_tags(self):
        os.environ["GRAPHSIGNAL_TAGS"] = "t1,t 2"

        wr = WorkloadRun()

        self.assertEqual(wr.tags, {
            't1': True,
            't 2': True
        })

    def test_env_params(self):
        os.environ["GRAPHSIGNAL_PARAMS"] = "p1: v1, p2 : 2 "

        wr = WorkloadRun()

        self.assertEqual(wr.params, {
            'p1': 'v1',
            'p2': '2'
        })

    def test_update_inference_stats(self):
        wr = WorkloadRun()

        wr.update_inference_stats(10, batch_size=128)
        wr.update_inference_stats(20, batch_size=128)
        self.assertEqual(wr.inference_count, 2)
        self.assertEqual(wr.total_time_us, 30)
        self.assertEqual(wr.sample_count, 2 * 128)

